<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://taamul.com
 * @since      1.0.2
 *
 * @package    Taamul
 * @subpackage Taamul/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Taamul
 * @subpackage Taamul/public
 * @author     Taamul <taamul.inc@gmail.com>
 */
class Taamul_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.2
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.2
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.2
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.2
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Taamul_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Taamul_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/taamul-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.2
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Taamul_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Taamul_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/taamul-public.js', array( 'jquery' ), $this->version, false );

	}
	
	public function taamul_layout_asst() {	
		wp_enqueue_style( $this->plugin_name.'_taamul_reset', plugin_dir_url( __FILE__ ) . 'css/taamul_reset.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name.'_taamul_style', plugin_dir_url( __FILE__ ) . 'css/taamul_style.css', array(), $this->version, 'all' );
		//wp_enqueue_script( $this->plugin_name.'_taamul_modernizr', plugin_dir_url( __FILE__ ) . 'js/taamul_modernizr.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( $this->plugin_name.'_taamul_main', plugin_dir_url( __FILE__ ) . 'js/taamul_main.js', array( 'jquery' ), $this->version, false );
		
	}
	
	public function taamul_layout_display() {	
		require_once plugin_dir_path( __FILE__ ) . 'partials/view_feedback.php';
	}

}
